==> activesite-5.x-1.04.tar.gz: activesite/node.tpl.php <==
<?php phptemplate_comment_wrapper(NULL, $node->type); ?>
<?php

/**
 * ------------------------
 * [RU] Шаблон документа.
 * ------------------------
 */

?><div id="node-<?php print $node->nid; ?>" class="c_node node<?php
	if ($sticky) {print ' node-sticky';}
	if (!$status) {print ' node-unpublished';}
	print ' node-nid_'.$node->nid;
	print ' node-type_'.$node->type;
	?>">
<div class="c_node-subStyle">

    <?php if ($page == 0): ?>
	<h2 class="c_node_title">
	    <a href="<?php print $node_url ?>" title="<?php print $title ?>"><?php print wordwrap($title, 37, "\n", TRUE); ?></a>
	</h2>
    <?php endif; ?>

    <?php if ($submitted): ?>
	<span class="c_node-submitted submitted"><?php
	    print
		t('Published') .' '.
		'<span class="username">' . t('!username', array('!username' => theme('username', $node))) .'</span> ' .
		'<span class="datetime">' . t('!datetime', array('!datetime' => format_date($node->created, 'custom', 'D, d/m/Y - H:i'))) . '</span> ' /*.
		'<span class="datetime">' . t('!datetime', array('!datetime' => format_date($node->changed, 'custom', 'D, d/m/Y - H:i'))) . '</span>' */ ;
      ?></span>
    <?php endif; ?>

    <?php if ($picture): ?>
	<div class="c_user_picture">
	    <?php print $picture ?>
	</div>
    <?php endif; ?>

    <div class="c_node_content content">
	<?php print $content ?>
    </div>

    <div class="c_clear">&nbsp;</div>

    <div class="meta">
	<?php if ($taxonomy): ?>
	    <div class="c_node_terms terms"><?php print $terms ?></div>
	<?php endif;?>
    </div>

    <?php if ($links): ?>
	<div class="c_node_links c_links"><?php print $links; ?></div>
    <?php endif; ?>

</div>
</div>

==> activesite-5.x-1.07.tar.gz: activesite/node.tpl.php <==
<?php phptemplate_comment_wrapper(NULL, $node->type); ?>
<?php

/**
 * ------------------------
 * [RU] Шаблон документа.
 * ------------------------
 */

?><div id="node-<?php print $node->nid; ?>" class="c_node node<?php
	if ($sticky) {print ' node-sticky';}
	if (!$status) {print ' node-unpublished';}
	print ' node-nid_'.$node->nid;
	print ' node-type_'.$node->type;
	?>">
<div class="c_node-subStyle">

    <?php if ($page == 0): ?>
	<h2 class="c_node_title">
	    <a href="<?php print $node_url ?>" title="<?php print $title ?>"><?php print $title; ?></a>
	</h2>
    <?php endif; ?>

    <?php if ($submitted): ?>
	<span class="c_node-submitted submitted"><?php
	    print
		t('Published') .' '.
		'<span class="username">' . t('!username', array('!username' => theme('username', $node))) .'</span> ' .
		'<span class="datetime">' . t('!datetime', array('!datetime' => format_date($node->created, 'custom', 'D, d/m/Y - H:i'))) . '</span> ' /*.
		'<span class="datetime">' . t('!datetime', array('!datetime' => format_date($node->changed, 'custom', 'D, d/m/Y - H:i'))) . '</span>' */ ;
      ?></span>
    <?php endif; ?>

    <?php if ($picture): ?>
	<div class="c_user_picture">
	    <?php print $picture ?>
	</div>
    <?php endif; ?>

    <div class="c_node_content content">
	<?php print $content ?>
    </div>

    <div class="c_clear">&nbsp;</div>

    <div class="meta">
	<?php if ($taxonomy): ?>
	    <div class="c_node_terms terms"><?php print $terms ?></div>
	<?php endif;?>
    </div>

    <?php if ($links): ?>
	<div class="c_node_links c_links"><?php print $links; ?></div>
    <?php endif; ?>

</div>
</div>
